{% extends 'siteapp/sections/costumer/site-query.html' %}
{% load crispy_forms_tags %}
{% load static %}
{% block head_title %} | Restablecer contraseña{% endblock %}
{% block content %}  
{% if request.user.is_authenticated %}
    <script>
        window.location.href = "{% url 'linkzone:console' %}"
    </script>
{% endif %}
<div class="container mx-auto login-view vh-100">
    <div class="row justify-content-center">
        <div class="col-sm-12 col-lg-8 pt-4 main-logo">
            <img src="{% static 'img/icons/login.png' %}" class="w-100">
        </div>
        <div class="col-sm-12 col-lg-8">
            <div class="instant-messages">
                {% if messages %}
                    {% for message in messages %}
                        <div class="alert alert-{{ message.tags }} alert-dismissible fade show" role="alert">
                            <span class="alert-inner--icon"><i class="ni ni-like-2"></i></span>
                            <span class="alert-inner--text">{{ message }}</span>
                            <button type="button" class="close" data-dismiss="alert" aria-label="close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                    {% endfor %}
                {% endif %}
            </div>
            <div class="p-4">
                {% if 'email' in request.get_full_path %}
                        <h3 class="mb-4 oxanium">Solicitud de nueva contraseña</h3>
                        <p>Revisa tu e-mail para instrucciones</p>
                {% endif%}
                {% if 'complete' in request.get_full_path %}
                        <h3 class="mb-4 oxanium text-center">Restablecimiento de contraseña exitoso</h3>
                        <a class="text-center btn link-zone btn-center" href="{% url 'accounts:login' %}">Login</a>
                {% endif%}
            </div>     
        </div>
    </div>
</div>
{% endblock  %}
