# Generated by Django 4.2.1 on 2023-11-13 22:37

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_design', 'Budget Design'), ('budget_development', 'Budget Development'), ('budget_marketing', 'Budget Marketing'), ('Monthly charge', 'Monthly charge'), ('Billing receipt', 'Billing receipt'), ('Others', 'Others')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('IT Development Services', 'IT Development Services'), ('Consulting', 'Consulting'), ('Media Creators', 'Media Creators'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('E-commerce', 'E-commerce'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Health and Wellness', 'Health and Wellness'), ('Education and Training', 'Education and Training')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-dark-blue', 'card-dark-blue'), ('card-tale', 'card-tale'), ('card-light-blue', 'card-light-blue'), ('card-light-danger', 'card-light-danger')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Tips and Tricks', 'Tips and Tricks'), ('Interviews', 'Interviews'), ('Tutorials', 'Tutorials'), ('Guides and Manuals', 'Guides and Manuals'), ('News', 'News'), ('Inspiration', 'Inspiration'), ('Events and Conferences', 'Events and Conferences')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 11, 13, 19, 36, 58, 762901)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Promotional Discount', 'Promotional Discount'), ('Initial Payment', 'Initial Payment'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('No Selected', 'No Selected')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Draft', 'Draft'), ('Send', 'Send')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2'), ('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Domains', 'Cloud Domains'), ('Stela Design', 'Stela Design'), ('Store', 'Store'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 3', 'Step 3'), ('Step 2', 'Step 2'), ('Step 4', 'Step 4')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('budget_design_terms', 'Budget Design Terms'), ('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions'), ('monthly_terms', 'Billing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Return Policy', 'Return Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Privacy Policy', 'Privacy Policy'), ('Disclaimer', 'Disclaimer')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Github', 'Github'), ('Linkedin', 'Linkedin'), ('Instagram', 'Instagram'), ('Tiktok', 'Tiktok'), ('Facebook', 'Facebook'), ('X', 'X'), ('Youtube', 'Youtube')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my project', 'I have a problem with my project'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Others', 'Others'), ('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Zelle', 'Zelle'), ('Binance', 'Binance'), ('Paypal', 'Paypal')], max_length=100, verbose_name='Type of Wallet'),
        ),
        migrations.CreateModel(
            name='ProStelaUsage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tokens', models.IntegerField(default=0)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('prompt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='prompt_data', to='stela_control.prosteladata')),
            ],
        ),
    ]
