# Generated by Django 5.0 on 2023-12-19 15:48

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0015_team_owner_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Billing receipt', 'Billing receipt'), ('Others', 'Others'), ('budget_development', 'Budget Development'), ('Monthly charge', 'Monthly charge'), ('budget_marketing', 'Budget Marketing'), ('budget_design', 'Budget Design')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('E-commerce', 'E-commerce'), ('IT Development Services', 'IT Development Services'), ('Consulting', 'Consulting'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Media Creators', 'Media Creators'), ('Education and Training', 'Education and Training'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Health and Wellness', 'Health and Wellness')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-dark-blue', 'card-dark-blue'), ('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('News', 'News'), ('Inspiration', 'Inspiration'), ('Interviews', 'Interviews'), ('Tips and Tricks', 'Tips and Tricks'), ('Guides and Manuals', 'Guides and Manuals'), ('Events and Conferences', 'Events and Conferences'), ('Tutorials', 'Tutorials')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 19, 12, 48, 10, 272954)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Initial Payment', 'Initial Payment'), ('Promotional Discount', 'Promotional Discount')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 1', 'Style Template 1'), ('Style Template 2', 'Style Template 2'), ('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains'), ('Store', 'Store'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected'), ('Stela Design', 'Stela Design')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 4', 'Step 4'), ('Step 3', 'Step 3')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Disclaimer', 'Disclaimer'), ('budget_design_terms', 'Budget Design Terms'), ('billing_terms', 'Monthly Billing Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('Return Policy', 'Return Policy'), ('budget_development_terms', 'Budget Development Terms'), ('monthly_terms', 'Billing Terms'), ('Privacy Policy', 'Privacy Policy'), ('Cookie Policy', 'Cookie Policy')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Facebook', 'Facebook'), ('Linkedin', 'Linkedin'), ('Github', 'Github'), ('Tiktok', 'Tiktok'), ('Instagram', 'Instagram'), ('X', 'X'), ('Youtube', 'Youtube'), ('Wikipedia', 'Wikipedia')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my project', 'I have a problem with my project'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Others', 'Others'), ('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue'), ('My delivery has been delayed', 'My delivery has been delayed')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Binance', 'Binance'), ('Zelle', 'Zelle'), ('Paypal', 'Paypal')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]
