{% extends 'stela_control/home.html' %}
{% load static %}
{% block body %}
{% block head_title %}. Stela Control Dynamic.{% endblock %}</title>
<div class="login_bg">
    <div class="row no-gutter justify-content-center">
        <div class="col-md-12 p-0">
            <div class="login d-flex align-items-center">
                    {% block content %}
                    {% endblock  %}
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock  %}