{% extends 'stela_control/payments/homebrew.html' %}
{% load i18n %}
{% load static %}
{% load crispy_forms_tags %}

{% block section %}
{% block title %}
            <h1 class="oxanium text-dark fs-2 pt-3">{% trans "Withdrawals" %} <i class="fa-solid fa-building-columns"></i></h1>
{% endblock  %}
{% block side_title %}
            <h3 class="oxanium d-flex justify-content-end"><b>STELA CONTROL DYNAMIC | {% trans "finances" %}</b></h3>
{% endblock  %}
<div class="container">
    <div class="row">
        <div class="col-lg-8">
            <div class="b-25px bg-white term-overlay mb-3 p-4">
                <div class="d-flex justify-content-center">
                    <h1 class="oxanium fs-3">{% trans "Withdraw Request" %}</h1>
                </div>
                <div class="row mt-5">
                    <div class="col-12">
                        <h3>{% trans "Receiving account" %}</h3>
                        <h3 class="fw-bold oxanium fs-5">{% trans "Bank Holder" %}: {{bank.user.first_name}} {{bank.user.last_name}} </h3>
                        <h3 class="fw-bold oxanium fs-5">{{bank.bank_name}}</h3>
                        <h3 class="fw-bold oxanium fs-5">{% trans "ending in" %} {{bank.account_number|slice:":-9"}}</h3>
                    </div>
                    <div class="col-12">
                        <h3>{% trans "Budget amount" %}</h3>
                        <h3 class="fs-5 oxanium text-success fw-bold">${{budget.total}}</h3>
                        <div class="d-flex justify-content-end">
                            <input type="hidden" id="bank" value="{{bank.id}}">
                            <button class="btn linkzone mt-3 fw-bold fs-5" id="send"> {% trans "Withdraw" %} <i class="fa-solid fa-wallet"></i></button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-lg-4">
            <div class="b-25px bg-white term-overlay mb-3 p-3">
                <div class="d-flex justify-content-center">
                    <h1 class="oxanium fs-4 fw-bold">{% trans "Stela Payments" %}</h1>
                </div>
                <div class="d-flex justify-content-center">
                    <h2 class="oxanium fs-5">{% trans "Withdraw conditions" %}</h2>
                </div>
                <div class="row">
                    <div class="col-12">
                        <ul class="mr-3">
                            <li class="text-justify">
        
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<script src="https://emmerutcdn.s3.amazonaws.com/static/js/stela/payments/withdraw.js"></script>
{% endblock %}