# Generated by Django 5.0 on 2023-12-19 17:32

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0001_initial'),
        ('geolocation', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='userbase',
            name='terms',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='userbase',
            name='city_profile',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.city', verbose_name='City'),
        ),
    ]
