# Generated by Django 4.2.1 on 2023-12-15 19:21

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0010_remove_booking_service_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='APIStelaClient',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('client_key', models.CharField(max_length=255, unique=True)),
                ('secret_key', models.CharField(max_length=255)),
                ('is_subscriber', models.BooleanField(default=False)),
            ],
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_development', 'Budget Development'), ('Others', 'Others'), ('Monthly charge', 'Monthly charge'), ('budget_design', 'Budget Design'), ('Billing receipt', 'Billing receipt'), ('budget_marketing', 'Budget Marketing')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Health and Wellness', 'Health and Wellness'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('E-commerce', 'E-commerce'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Media Creators', 'Media Creators'), ('Consulting', 'Consulting'), ('Education and Training', 'Education and Training'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('IT Development Services', 'IT Development Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue'), ('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Interviews', 'Interviews'), ('Guides and Manuals', 'Guides and Manuals'), ('News', 'News'), ('Events and Conferences', 'Events and Conferences'), ('Tips and Tricks', 'Tips and Tricks'), ('Tutorials', 'Tutorials'), ('Inspiration', 'Inspiration')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 15, 16, 21, 25, 404685)),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Draft', 'Draft'), ('Send', 'Send')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 2', 'Style Template 2'), ('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4'), ('Style Template 1', 'Style Template 1')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Cloud Domains', 'Cloud Domains'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected'), ('Stela Marketing', 'Stela Marketing'), ('Store', 'Store'), ('Stela Design', 'Stela Design'), ('Stela Websites', 'Stela Websites')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 4', 'Step 4'), ('Step 3', 'Step 3'), ('Step 2', 'Step 2')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Disclaimer', 'Disclaimer'), ('Privacy Policy', 'Privacy Policy'), ('billing_terms', 'Monthly Billing Terms'), ('monthly_terms', 'Billing Terms'), ('Return Policy', 'Return Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('budget_design_terms', 'Budget Design Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Tiktok', 'Tiktok'), ('Github', 'Github'), ('Youtube', 'Youtube'), ('Linkedin', 'Linkedin'), ('Facebook', 'Facebook'), ('X', 'X'), ('Instagram', 'Instagram')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My account has an error', 'My account has an error'), ('I have a problem with my project', 'I have a problem with my project'), ('Others', 'Others'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Payments Issue', 'Payments Issue')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
    ]
