{% load i18n %}
{% for row in customer %}
    <div class="form-group mx-4 my-2">
        <label for="client">{% trans "Full Name" %}</label>
        <input class="form-control" value="{{row.full_name}}" type="text" name="client" id="client">
    </div>
    <div class="form-group mx-4 my-2">
        <label for="client">{% trans "ID or EIN" %}</label>
        <input class="form-control" value="{{row.userid}}" type="text" name="userid" id="userid">
    </div>
    <div class="form-group mx-4 my-2">
        <label for="client">{% trans "Phone" %}</label>
        <input class="form-control" value="{{row.phone}}" type="text" name="phone" id="phone">
    </div>
    <div class="form-group mx-4 mt-2 mb-4">
        <label for="client">{% trans "Address" %}</label>
        <input class="form-control" value="{{row.address}}" type="text" name="address" id="address">
    </div>
{% endfor %}